Documentation
¶
Index ¶
- Variables
- func GetFullPrefix(manager filemanager.FileManager, prefix string) (fullPrefix string)
- func GetStorageDateFormat(manager filemanager.FileManager, destination *DestinationT, folderName string) (dateFormat string, err error)
- func Init()
- func Init2()
- func IsAsyncDestination(destType string) bool
- func IsObjectStorageDestination(destType string) bool
- func IsWarehouseDestination(destType string) bool
- type AsyncPollT
- type AsyncStatusResponse
- type BatchDestinationDataT
- type BatchJobsT
- type BatchRouterAdmin
- type DestinationT
- type ErrorResponseT
- type Factory
- type HandleT
- type JobParametersT
- type ObjectStorageT
- type StorageUploadOutput
Constants ¶
This section is empty.
Variables ¶
var (
Diagnostics diagnostics.DiagnosticsI
)
Functions ¶
func GetFullPrefix ¶ added in v0.1.10
func GetFullPrefix(manager filemanager.FileManager, prefix string) (fullPrefix string)
func GetStorageDateFormat ¶ added in v0.1.10
func GetStorageDateFormat(manager filemanager.FileManager, destination *DestinationT, folderName string) (dateFormat string, err error)
func IsAsyncDestination ¶ added in v0.1.10
func IsObjectStorageDestination ¶ added in v0.1.10
func IsWarehouseDestination ¶ added in v0.1.10
Types ¶
type AsyncPollT ¶ added in v0.1.10
type AsyncStatusResponse ¶ added in v0.1.10
type BatchDestinationDataT ¶ added in v0.1.10
type BatchDestinationDataT struct {
// contains filtered or unexported fields
}
type BatchJobsT ¶
type BatchJobsT struct {
Jobs []*jobsdb.JobT
BatchDestination *DestinationT
TimeWindow time.Time
}
type BatchRouterAdmin ¶ added in v0.1.10
type BatchRouterAdmin struct {
// contains filtered or unexported fields
}
func (*BatchRouterAdmin) Status ¶ added in v0.1.10
func (ba *BatchRouterAdmin) Status() interface{}
Status function is used for debug purposes by the admin interface
type DestinationT ¶
type DestinationT struct {
Source backendconfig.SourceT
Destination backendconfig.DestinationT
}
type ErrorResponseT ¶
type ErrorResponseT struct {
Error string
}
type Factory ¶ added in v0.1.10
type Factory struct {
Reporting types.ReportingI
Multitenant multitenant.MultiTenantI
BackendConfig backendconfig.BackendConfig
RouterDB jobsdb.JobsDB
ProcErrorDB jobsdb.JobsDB
TransientSources transientsource.Service
RsourcesService rsources.JobService
}
type HandleT ¶
type HandleT struct {
// contains filtered or unexported fields
}
func (*HandleT) GetWorkspaceIDForDestID ¶ added in v0.1.10
func (*HandleT) Setup ¶
func (brt *HandleT) Setup(backendConfig backendconfig.BackendConfig, jobsDB, errorDB jobsdb.JobsDB, destType string, reporting types.ReportingI, multitenantStat multitenant.MultiTenantI, transientSources transientsource.Service, rsourcesService rsources.JobService)
Setup initializes this module
type JobParametersT ¶ added in v0.1.10
type JobParametersT struct {
SourceID string `json:"source_id"`
DestinationID string `json:"destination_id"`
ReceivedAt string `json:"received_at"`
TransformAt string `json:"transform_at"`
SourceBatchID string `json:"source_batch_id"`
SourceTaskID string `json:"source_task_id"`
SourceTaskRunID string `json:"source_task_run_id"`
SourceJobID string `json:"source_job_id"`
SourceJobRunID string `json:"source_job_run_id"`
SourceDefinitionID string `json:"source_definition_id"`
DestinationDefinitionID string `json:"destination_definition_id"`
SourceCategory string `json:"source_category"`
EventName string `json:"event_name"`
EventType string `json:"event_type"`
MessageID string `json:"message_id"`
}
JobParametersT struct holds source id and destination id of a job
type ObjectStorageT ¶
Click to show internal directories.
Click to hide internal directories.