Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Strategy ¶
type Strategy interface {
// ActivePartitions returns the list of partitions that are active for the given strategy
ActivePartitions(ctx context.Context, db jobsdb.JobsDB) ([]string, error)
// AugmentQueryParams augments the given GetQueryParamsT with the strategy specific parameters
AugmentQueryParams(partition string, params *jobsdb.GetQueryParamsT)
// StopIteration returns true if the iteration should be stopped for the given error
StopIteration(err error) bool
}
Strategy defines the operations that every different isolation strategy in processor must implement
Click to show internal directories.
Click to hide internal directories.